NC type mapping and helper functions for the classic (CDF-1/2/5) format.
Constants
Functions
- nc_
type_ from_ code - Convert a classic NC type code to an
NcType. - nc_
type_ size - Size of one element for a classic NC type code.
- pad_
to_ 4 - Round up to the next 4-byte boundary.
- padding_
to_ 4 - Compute the amount of padding needed to reach a 4-byte boundary.