pub struct NcVariable {
pub name: String,
pub dimensions: Vec<NcDimension>,
pub dtype: NcType,
pub attributes: Vec<NcAttribute>,
/* private fields */
}Expand description
A NetCDF variable (metadata only – data is read on demand).
Fields
name: Stringdimensions: Vec<NcDimension>dtype: NcTypeattributes: Vec<NcAttribute>Implementations
Sourceimpl NcVariable
impl NcVariable
Sourcepub fn dimensions(&self) -> &[NcDimension]
pub fn dimensions(&self) -> &[NcDimension]
Variable dimensions.
Sourcepub fn coordinate_dimension(&self) -> Option<&NcDimension>
pub fn coordinate_dimension(&self) -> Option<&NcDimension>
Returns the dimension for a CF/NetCDF coordinate variable.
A coordinate variable is one-dimensional and has the same name as its dimension. NetCDF-4 stores these as HDF5 dimension scales, but they are exposed here with the same shape as classic NetCDF coordinate variables.
Sourcepub fn is_coordinate_variable(&self) -> bool
pub fn is_coordinate_variable(&self) -> bool
Returns true when this variable is a CF/NetCDF coordinate variable.
Sourcepub fn is_coordinate_variable_for(&self, dimension_name: &str) -> bool
pub fn is_coordinate_variable_for(&self, dimension_name: &str) -> bool
Returns true when this variable is the coordinate variable for a named dimension.
Sourcepub fn attributes(&self) -> &[NcAttribute]
pub fn attributes(&self) -> &[NcAttribute]
Variable attributes.
Sourcepub fn attribute(&self, name: &str) -> Option<&NcAttribute>
pub fn attribute(&self, name: &str) -> Option<&NcAttribute>
Find an attribute by name.
Sourcepub fn num_elements(&self) -> u64
pub fn num_elements(&self) -> u64
Total number of elements.