Data reading for classic (CDF-1/2/5) NetCDF files.
Two layout types:
- Non-record variables: contiguous data at the offset stored in the variable header.
- Record variables: data is interleaved across records. Each record contains one slice from every record variable, in the order they appear in the header. The total record size is the sum of all record variables’ vsize values (each padded to 4-byte boundary in CDF-1/2).
Traits
- NcRead
Type - Trait for types that can be read from classic NetCDF data.
Functions
- compute_
record_ stride - Compute the record stride: total bytes per record across all record variables.
- read_
non_ record_ variable - Read the entire data for a non-record variable into an ndarray.
- read_
record_ variable - Read the entire data for a record variable into an ndarray.