Module types

Module types 

NC type mapping and helper functions for the classic (CDF-1/2/5) format.

Constants

NC_BYTE
NC_CHAR
NC_DOUBLE
NC_FLOAT
NC_INT
NC_INT64
NC_SHORT
NC_UBYTE
NC_UINT
NC_UINT64
NC_USHORT

Functions

nc_type_from_code
Convert a classic NC type code to an NcType.
nc_type_size
Size of one element for a classic NC type code.
pad_to_4
Round up to the next 4-byte boundary.
padding_to_4
Compute the amount of padding needed to reach a 4-byte boundary.