NcReadable

Trait NcReadable 

pub trait NcReadable: NcReadType + H5Type { }
Trait alias for types readable from both classic and NetCDF-4 files.

This unifies classic::data::NcReadType (for CDF-1/2/5) and hdf5_reader::H5Type (for NetCDF-4/HDF5) so that NcFile::read_variable works across all formats with a single type parameter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: NcReadType + H5Type> NcReadable for T

Available on crate feature netcdf4 only.